@@ -3,13 +3,14 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate test stubs for methods and functions
 
-our $VERSION = '0.0503';
+our $VERSION = '0.0600';
 
 use Moo;
 use strictures 2;
 use namespace::clean;
 
-use Class::Sniff;
+use Package::Stash;
+use Sub::Identify 'stash_name';
 
 
 has module => (
@@ -40,8 +41,17 @@ has subs => (
 sub gather_subs {
     my ($self) = @_;
 
-    my $sniff = Class::Sniff->new({ class => $self->module });
-    my @subs = $sniff->methods;
+    my $class = $self->module;
+    eval "require $class";
+    die "Can't load $class: $@" if $@;
+    my $subs = Package::Stash->new($class)->get_all_symbols('CODE');
+
+    my @subs;
+    for my $sub ( keys %$subs ) {
+        my $packagename = stash_name($subs->{$sub});
+        push @subs, $sub if $packagename eq $class;
+    }
+
     my %subs;
     @subs{@subs} = undef;
 
@@ -120,11 +130,11 @@ Test::NaiveStubs - Generate test stubs for methods and functions
 
 =head1 VERSION
 
-version 0.0503
+version 0.0600
 
 =head1 SYNOPSIS
 
-  #use Foo::Bar; # <- Uncomment to load the Foo::Bar module
+  #use Foo::Bar; # <- Uncomment to load and inspect the module
   use Test::NaiveStubs;
 
   my $tns = Test::NaiveStubs->new(
@@ -211,7 +221,17 @@ the subroutine is produced.
 
 L<Moo>
 
-L<Class::Sniff>
+L<Package::Stash>
+
+L<Sub::Identify>
+
+=head1 THANK YOU
+
+For helping me understand how to gather the subroutines:
+
+Dan Book (DBOOK)
+
+Matt S Trout (MSTROUT)
 
 =head1 AUTHOR
 
